
import os
from ctypes import cdll, c_int, c_double, POINTER
import ctypes as C
import array as arr

#use for converting array into a pointer. 
c_double_p = C.POINTER(C.c_double)
c_int_p    = C.POINTER(C.c_int)


if __name__ == '__main__':

    print("..loading OceanMathCore.dll....")

    os.add_dll_directory(os.getcwd()) 
    os.add_dll_directory(r'C:\Program Files\Ocean Insight\OceanMath-1.05\lib')
    os.add_dll_directory(r'C:\Program Files\Ocean Insight\OceanMath-1.05')


    oceanmath = cdll.LoadLibrary("OceanMathCore.dll")

    pixelCount  = 1024
    wavelengths = (c_double * pixelCount)(0)
    blackBody   = (c_double * pixelCount)(0)
    colorTemperature = 6500.0
    
    print("wavelengths size =  %d" % (len(wavelengths)))
    
    #set up wavelengths at 0.5nm intevals starting at 300nm
    for pixel in range(pixelCount):
        wavelengths[pixel] = 300.0 + pixel * 0.5
        #print("%d = %f" % (pixel, wavelengths[pixel]))

    black_body = oceanmath.omapi_calculate_blackbody_spectrum_unnormalized
    black_body.argtypes = [C.c_double, c_double_p, C.c_int, c_double_p, c_int_p]
    black_body.restype  = C.c_int
    
    err_cp = (c_int * 1)(0)
    actualPixels = black_body(colorTemperature, C.cast(wavelengths, c_double_p), pixelCount,
                              C.cast(blackBody, c_double_p), C.cast(err_cp, c_int_p))

    if err_cp[0] != 0:
        print("ERROR: Calculation error with error code =  %d" % (err_cp[0]))
    else:
        print("actualPixels = %d" % (actualPixels))
        
        #Find the spectrum peak value and index
        peakPixelIndex = -1
        peakSpectrum   = 0.0
        
        for pixel in range(pixelCount):
            if blackBody[pixel] > peakSpectrum:
                peakSpectrum   = blackBody[pixel]
                peakPixelIndex = pixel
                
        #Convert the peak wavelength from nm to microns
        peakWavelengthMicrons = wavelengths[peakPixelIndex] / 1000.0;

        print("Peak value is %f Watts per square metre per micron per steradian at wavelength %f microns"
              % (peakSpectrum, peakWavelengthMicrons) );

    print("**** exiting program ****")
    

